Slicer package manager Python Client
====================================

Installation
------------

Since no package is available on PyPi, you must install from source.

First obtain the source code::

    $ git clone https://github.com/girder/slicer_package_manager.git
    $ cd slicer_package_manager/python_client

Then install with::

    $ pip install .

or::

    $ pip install -e .

for development.

Miscellaneous
-------------

The documentation is accessible at https://slicer-package-manager.readthedocs.io/en/latest/commands_shell.html#slicer-package-manager-client.

